==> 0.5.0.tar.gz: lib/widgets/senior_button.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import 'senior_elevated_element.dart';

enum SeniorButtonSize { small, big }
enum SeniorButtonType { primary, secondary, ghost }

class SeniorButtonTheme {
  SeniorButtonTheme._();

  static double getButtonHeight({required SeniorButtonSize size}) {
    switch (size) {
      case SeniorButtonSize.big:
        return 48.0;
      case SeniorButtonSize.small:
      default:
        return 40.0;
    }
  }

  static Color getButtonTextColor(
      {required Brightness theme,
      required SeniorButtonType type,
      required bool isDisabled}) {
    switch (type) {
      case SeniorButtonType.ghost:
        return !isDisabled
            ? SeniorColors.primaryColor
            : SeniorColors.primaryColor100;
      case SeniorButtonType.secondary:
        return !isDisabled
            ? SeniorColors.pureWhite
            : SeniorColors.secondaryColor400;
      case SeniorButtonType.primary:
      default:
        return !isDisabled
            ? SeniorColors.pureWhite
            : SeniorColors.primaryColor300;
    }
  }

  static TextStyle getButtonTextStyle(
      {required Brightness theme,
      required SeniorButtonType type,
      required bool isDisabled}) {
    return SeniorTypography.cta(
        color: getButtonTextColor(
            theme: theme, type: type, isDisabled: isDisabled));
  }

  static ButtonStyle getButtonStyle({
    required Brightness theme,
    required SeniorButtonType type,
    required bool isDisabled,
  }) {
    return ButtonStyle(
      overlayColor: MaterialStateProperty.all<Color>(_getButtonHighlightColor(
        theme: theme,
        type: type,
      )),
      backgroundColor: MaterialStateProperty.all<Color>(_getButtonColor(
        theme: theme,
        type: type,
        isDisabled: isDisabled,
      )),
      shape: MaterialStateProperty.all<OutlinedBorder>(
        new RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular(SeniorRadius.xbig),
        ),
      ),
      //A elevação é configurada pelo SeniorElevatedElement
      elevation: MaterialStateProperty.all<double>(0),
    );
  }

  static Color _getButtonColor(
      {required Brightness theme,
      required SeniorButtonType type,
      required bool isDisabled}) {
    switch (type) {
      case SeniorButtonType.ghost:
        return Colors.transparent;
      case SeniorButtonType.secondary:
        return !isDisabled
            ? SeniorColors.secondaryColor600
            : SeniorColors.secondaryColor100;
      case SeniorButtonType.primary:
      default:
        return !isDisabled
            ? SeniorColors.primaryColor
            : SeniorColors.primaryColor100;
    }
  }

  static Color _getButtonHighlightColor(
      {required Brightness theme, required SeniorButtonType type}) {
    switch (type) {
      case SeniorButtonType.ghost:
        return SeniorColors.neutralColor400;
      case SeniorButtonType.secondary:
        return SeniorColors.secondaryColor100;
      case SeniorButtonType.primary:
      default:
        return SeniorColors.primaryColor100;
    }
  }
}

class SeniorButton extends StatelessWidget {
  final String label;
  final bool disabled;
  final Function() onPressed;
  final SeniorButtonType type;
  final SeniorButtonSize size;
  final bool fullLength;
  final bool busy;

  const SeniorButton({
    Key? key,
    required this.label,
    this.disabled = false,
    required this.onPressed,
    this.type = SeniorButtonType.primary,
    this.size = SeniorButtonSize.small,
    this.fullLength = false,
    this.busy = false,
  }) : super(key: key);

  factory SeniorButton.icon({
    Key? key,
    required String label,
    bool disabled,
    required Function() onPressed,
    required IconData icon,
    SeniorButtonType type,
    SeniorButtonSize size,
    bool fullLength,
  }) = _SeniorButtonIcon;

  Widget buildButton({required Brightness theme}) {
    return SeniorElevatedElement(
      child: ElevatedButton(
        key: this.key,
        child: Visibility(
          visible: !this.busy,
          child: Text(
            this.label,
            style: SeniorButtonTheme.getButtonTextStyle(
              theme: theme,
              type: this.type,
              isDisabled: this.disabled,
            ),
          ),
          replacement: CircularProgressIndicator(),
        ),
        onPressed: !this.disabled ? this.onPressed : null,
        style: SeniorButtonTheme.getButtonStyle(
          theme: theme,
          type: this.type,
          isDisabled: this.disabled,
        ),
      ),
      elevation: this.disabled || this.type == SeniorButtonType.ghost
          ? SeniorElevations.dp0
          : SeniorElevations.dp01,
      borderRadius: SeniorRadius.xbig,
    );
  }

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return SizedBox(
      child: this.buildButton(theme: theme),
      height: SeniorButtonTheme.getButtonHeight(
        size: this.size,
      ),
      width: this.fullLength ? double.infinity : null,
    );
  }
}

class _SeniorButtonIcon extends SeniorButton {
  final IconData icon;

  _SeniorButtonIcon({
    Key? key,
    required String label,
    bool disabled = false,
    required Function() onPressed,
    required this.icon,
    SeniorButtonType type = SeniorButtonType.primary,
    SeniorButtonSize size = SeniorButtonSize.small,
    bool fullLength = false,
  }) : super(
          key: key,
          label: label,
          disabled: disabled,
          onPressed: onPressed,
          type: type,
          size: size,
          fullLength: fullLength,
        );

  @override
  Widget buildButton({required Brightness theme}) {
    return SeniorElevatedElement(
      child: ElevatedButton.icon(
        label: Text(
          this.label,
          style: SeniorButtonTheme.getButtonTextStyle(
            theme: theme,
            type: this.type,
            isDisabled: this.disabled,
          ),
        ),
        icon: FaIcon(
          this.icon,
          size: SeniorTypographyIconSize.CTA,
          color: SeniorButtonTheme.getButtonTextColor(
            theme: theme,
            type: this.type,
            isDisabled: this.disabled,
          ),
        ),
        onPressed: !this.disabled ? this.onPressed : null,
        style: SeniorButtonTheme.getButtonStyle(
          theme: theme,
          type: this.type,
          isDisabled: this.disabled,
        ),
      ),
      elevation: this.disabled || this.type == SeniorButtonType.ghost
          ? SeniorElevations.dp0
          : SeniorElevations.dp01,
      borderRadius: SeniorRadius.xbig,
    );
  }
}

==> 0.7.2.tar.gz: lib/widgets/senior_button.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import 'senior_elevated_element.dart';

enum SeniorButtonSize { small, big }
enum SeniorButtonType { primary, secondary, ghost, danger }

class SeniorButtonTheme {
  SeniorButtonTheme._();

  static double getButtonHeight({required SeniorButtonSize size}) {
    switch (size) {
      case SeniorButtonSize.big:
        return 48.0;
      case SeniorButtonSize.small:
      default:
        return 40.0;
    }
  }

  static Color getButtonTextColor({
    required SeniorButtonType type,
    required bool isDisabled,
  }) {
    switch (type) {
      case SeniorButtonType.ghost:
        return isDisabled
            ? SeniorColors.primaryColor100
            : SeniorColors.primaryColor;
      case SeniorButtonType.secondary:
        return isDisabled
            ? SeniorColors.secondaryColor400
            : SeniorColors.pureWhite;
      case SeniorButtonType.danger:
        return SeniorColors.pureWhite;
      case SeniorButtonType.primary:
      default:
        return isDisabled
            ? SeniorColors.primaryColor300
            : SeniorColors.pureWhite;
    }
  }

  static TextStyle getButtonTextStyle({
    required SeniorButtonType type,
    required bool isDisabled,
  }) {
    return SeniorTypography.cta(
      color: getButtonTextColor(
        type: type,
        isDisabled: isDisabled,
      ),
    );
  }

  static ButtonStyle getButtonStyle({
    required SeniorButtonType type,
    required bool isDisabled,
  }) {
    return ButtonStyle(
      overlayColor: MaterialStateProperty.all<Color>(_getButtonHighlightColor(
        type: type,
      )),
      backgroundColor: MaterialStateProperty.all<Color>(_getButtonColor(
        type: type,
        isDisabled: isDisabled,
      )),
      shape: MaterialStateProperty.all<OutlinedBorder>(
        new RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular(SeniorRadius.xbig),
        ),
      ),
      //A elevação é configurada pelo SeniorElevatedElement
      elevation: MaterialStateProperty.all<double>(0),
    );
  }

  static Color _getButtonColor({
    required SeniorButtonType type,
    required bool isDisabled,
  }) {
    switch (type) {
      case SeniorButtonType.ghost:
        return Colors.transparent;
      case SeniorButtonType.secondary:
        return isDisabled
            ? SeniorColors.secondaryColor100
            : SeniorColors.secondaryColor600;
      case SeniorButtonType.danger:
        return isDisabled
            ? SeniorColors.manchesterColorRed300
            : SeniorColors.manchesterColorRed500;
      case SeniorButtonType.primary:
      default:
        return isDisabled
            ? SeniorColors.primaryColor100
            : SeniorColors.primaryColor;
    }
  }

  static Color _getButtonHighlightColor({required SeniorButtonType type}) {
    switch (type) {
      case SeniorButtonType.ghost:
        return SeniorColors.neutralColor400;
      case SeniorButtonType.secondary:
        return SeniorColors.secondaryColor100;
      case SeniorButtonType.primary:
      default:
        return SeniorColors.primaryColor100;
    }
  }
}

class SeniorButton extends StatelessWidget {
  final String label;
  final bool disabled;
  final Function() onPressed;
  final SeniorButtonType type;
  final SeniorButtonSize size;
  final bool fullLength;
  final bool busy;

  const SeniorButton({
    Key? key,
    required this.label,
    this.disabled = false,
    required this.onPressed,
    this.type = SeniorButtonType.primary,
    this.size = SeniorButtonSize.small,
    this.fullLength = false,
    this.busy = false,
  }) : super(key: key);

  factory SeniorButton.icon({
    Key? key,
    required String label,
    bool disabled,
    required Function() onPressed,
    required IconData icon,
    SeniorButtonType type,
    SeniorButtonSize size,
    bool fullLength,
  }) = _SeniorButtonIcon;

  Widget buildButton() {
    return SeniorElevatedElement(
      child: ElevatedButton(
        key: this.key,
        child: Visibility(
          visible: !this.busy,
          child: Text(
            this.label,
            style: SeniorButtonTheme.getButtonTextStyle(
              type: this.type,
              isDisabled: this.disabled,
            ),
          ),
          replacement: CircularProgressIndicator(),
        ),
        onPressed: !this.disabled ? this.onPressed : null,
        style: SeniorButtonTheme.getButtonStyle(
          type: this.type,
          isDisabled: this.disabled,
        ),
      ),
      elevation: this.disabled || this.type == SeniorButtonType.ghost
          ? SeniorElevations.dp0
          : SeniorElevations.dp01,
      borderRadius: SeniorRadius.xbig,
    );
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      child: this.buildButton(),
      height: SeniorButtonTheme.getButtonHeight(
        size: this.size,
      ),
      width: this.fullLength ? double.infinity : null,
    );
  }
}

class _SeniorButtonIcon extends SeniorButton {
  final IconData icon;

  _SeniorButtonIcon({
    Key? key,
    required String label,
    bool disabled = false,
    required Function() onPressed,
    required this.icon,
    SeniorButtonType type = SeniorButtonType.primary,
    SeniorButtonSize size = SeniorButtonSize.small,
    bool fullLength = false,
  }) : super(
          key: key,
          label: label,
          disabled: disabled,
          onPressed: onPressed,
          type: type,
          size: size,
          fullLength: fullLength,
        );

  @override
  Widget buildButton() {
    return SeniorElevatedElement(
      child: ElevatedButton.icon(
        label: Text(
          this.label,
          style: SeniorButtonTheme.getButtonTextStyle(
            type: this.type,
            isDisabled: this.disabled,
          ),
        ),
        icon: FaIcon(
          this.icon,
          size: SeniorTypographyIconSize.CTA,
          color: SeniorButtonTheme.getButtonTextColor(
            type: this.type,
            isDisabled: this.disabled,
          ),
        ),
        onPressed: !this.disabled ? this.onPressed : null,
        style: SeniorButtonTheme.getButtonStyle(
          type: this.type,
          isDisabled: this.disabled,
        ),
      ),
      elevation: this.disabled || this.type == SeniorButtonType.ghost
          ? SeniorElevations.dp0
          : SeniorElevations.dp01,
      borderRadius: SeniorRadius.xbig,
    );
  }
}
